# Behavior Analysis Pipeline
Pipeline for analyzing behavioral videos
1. Precise normalization of videos (correct for setup differences between videos and lens warping)
2. Customize behaviour analysis with a fast, parallelized interface. 
3. Easily change analysis parameters such as timeslices, zone sizes, and more.
4. Data formats that are easy to share.
5. Works with DeepLabCut, SLEAP, and more!d.

## Usage
Most of the work to use this pipeline involves formatting data.

## Demo
Calculating total distance

## View experiment results through a real-time Dashboard

## Napari Zone-Drawing
